@@ -3,9 +3,11 @@ use 5.008005;
 use strict;
 use warnings;
 use parent 'Nephia::Setup::Plugin';
-use Nephia::Setup::Plugin::Assets::Bootstrap::Archive_2_3_2;
+use File::ShareDir ':ALL';
+use File::Copy;
+use File::Spec;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 our $ARCHIVE_FILENAME = 'bootstrap-2.3.2.zip';
 
 sub fix_setup {
@@ -15,8 +17,9 @@ sub fix_setup {
 
 sub _assets_bootstrap {
     my ($setup, $context) = @_;
-    my $data = Nephia::Setup::Plugin::Assets::Bootstrap::Archive_2_3_2->data;
-    $setup->spew($ARCHIVE_FILENAME, $data); 
+    my $src = module_file(__PACKAGE__, $ARCHIVE_FILENAME);
+    my $dst = File::Spec->catfile($setup->approot, $ARCHIVE_FILENAME);
+    copy($src, $dst);
     $setup->assets_archive($ARCHIVE_FILENAME, qw/static/);
 }
 
